# icat-plus-client
ICAT+ RESTful API with Swagger

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.0
- Package version: 1.0.0
- Generator version: 7.8.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import icat_plus_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import icat_plus_client
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import icat_plus_client
from icat_plus_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://icatplus.esrf.fr
# See configuration.py for a list of all supported configuration parameters.
configuration = icat_plus_client.Configuration(
    host = "https://icatplus.esrf.fr"
)



# Enter a context with an instance of the API client
with icat_plus_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = icat_plus_client.ActionsApi(api_client)
    session_id = '83825a51-69b8-4eg58-b5fb-bcf79bb412be' # str | session identifier provided by the metadata catalogue
    action = 'action_example' # str | identifier of the action (optional)

    try:
        # Actions related to the field instrumentName of the logbook
        api_response = api_instance.actions_session_id_logbook_instrumentname_put(session_id, action=action)
        print("The response of ActionsApi->actions_session_id_logbook_instrumentname_put:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling ActionsApi->actions_session_id_logbook_instrumentname_put: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://icatplus.esrf.fr*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ActionsApi* | [**actions_session_id_logbook_instrumentname_put**](docs/ActionsApi.md#actions_session_id_logbook_instrumentname_put) | **PUT** /actions/{sessionId}/logbook/instrumentname | Actions related to the field instrumentName of the logbook
*CacheApi* | [**cache_get**](docs/CacheApi.md#cache_get) | **GET** /cache | Gets the cache of a user given a specific sessionId
*CacheApi* | [**cache_keys_get**](docs/CacheApi.md#cache_keys_get) | **GET** /cache/keys | Gets the keys stored in the cache
*CacheApi* | [**cache_keys_key_get**](docs/CacheApi.md#cache_keys_key_get) | **GET** /cache/keys/{key} | Gets the content of a key
*CacheApi* | [**cache_session_id_post**](docs/CacheApi.md#cache_session_id_post) | **POST** /cache/{sessionId} | Reloads the cache
*CacheApi* | [**cache_stats_get**](docs/CacheApi.md#cache_stats_get) | **GET** /cache/stats | Gets the statistics for the use of cache
*CatalogueApi* | [**catalogue_instruments_get**](docs/CatalogueApi.md#catalogue_instruments_get) | **GET** /catalogue/instruments | Returns all instruments
*CatalogueApi* | [**catalogue_investigation_name_investigation_name_normalize_get**](docs/CatalogueApi.md#catalogue_investigation_name_investigation_name_normalize_get) | **GET** /catalogue/investigation/name/{investigationName}/normalize | Most of users don&#39;t write their proposal names using the same convention so it might happen that a given proposal can be written in many different ways. This method will homogenize such name.  Example IH-LS-0001, ihls0001, ih-LS-0001 are normalized like IH-LS-0001.
*CatalogueApi* | [**catalogue_parameters_get**](docs/CatalogueApi.md#catalogue_parameters_get) | **GET** /catalogue/parameters | Returns all parameters
*CatalogueApi* | [**catalogue_session_id_datacollection_get**](docs/CatalogueApi.md#catalogue_session_id_datacollection_get) | **GET** /catalogue/{sessionId}/datacollection | Gets all datacollection or for a given datasetId
*CatalogueApi* | [**catalogue_session_id_datafile_download_get**](docs/CatalogueApi.md#catalogue_session_id_datafile_download_get) | **GET** /catalogue/{sessionId}/datafile/download | Downloads a file given its filepath.
*CatalogueApi* | [**catalogue_session_id_datafile_get**](docs/CatalogueApi.md#catalogue_session_id_datafile_get) | **GET** /catalogue/{sessionId}/datafile | Get datafiles for a given dataset id.
*CatalogueApi* | [**catalogue_session_id_dataset_get**](docs/CatalogueApi.md#catalogue_session_id_dataset_get) | **GET** /catalogue/{sessionId}/dataset | Gets datasets for a given investigationId or for a given datasetIds of for a sampleId or for a beamline
*CatalogueApi* | [**catalogue_session_id_dataset_id_dataset_id_datacollection_get**](docs/CatalogueApi.md#catalogue_session_id_dataset_id_dataset_id_datacollection_get) | **GET** /catalogue/{sessionId}/dataset/id/{datasetId}/datacollection | Returns datacollections related to a given dataset along with a datasetId
*CatalogueApi* | [**catalogue_session_id_dataset_id_dataset_id_datafile_get**](docs/CatalogueApi.md#catalogue_session_id_dataset_id_dataset_id_datafile_get) | **GET** /catalogue/{sessionId}/dataset/id/{datasetId}/datafile | Get datafiles for a given dataset id. Method replaced by /catalogue/{sessionId}/datafile
*CatalogueApi* | [**catalogue_session_id_dataset_id_dataset_ids_dataset_document_get**](docs/CatalogueApi.md#catalogue_session_id_dataset_id_dataset_ids_dataset_document_get) | **GET** /catalogue/{sessionId}/dataset/id/{datasetIds}/dataset_document | Get a list of dataset documents from a datasetId list. A dataset document is used for indexing a dataset in elastic search. It unflatters dataset&#39;s parameters.
*CatalogueApi* | [**catalogue_session_id_dataset_id_dataset_ids_dataset_get**](docs/CatalogueApi.md#catalogue_session_id_dataset_id_dataset_ids_dataset_get) | **GET** /catalogue/{sessionId}/dataset/id/{datasetIds}/dataset | Get a list of dataset from a datasetId list
*CatalogueApi* | [**catalogue_session_id_dataset_startdate_start_date_enddate_end_date_dataset_document_get**](docs/CatalogueApi.md#catalogue_session_id_dataset_startdate_start_date_enddate_end_date_dataset_document_get) | **GET** /catalogue/{sessionId}/dataset/startdate/{startDate}/enddate/{endDate}/dataset_document | Get a list of dataset documents by date range. A dataset document is used for indexing a dataset in elastic search. It unflatters dataset&#39;s parameters.
*CatalogueApi* | [**catalogue_session_id_dataset_timeline_get**](docs/CatalogueApi.md#catalogue_session_id_dataset_timeline_get) | **GET** /catalogue/{sessionId}/dataset/timeline | Gets datasets timeline for a given investigationId or sampleId
*CatalogueApi* | [**catalogue_session_id_datasetparameter_get**](docs/CatalogueApi.md#catalogue_session_id_datasetparameter_get) | **GET** /catalogue/{sessionId}/datasetparameter | Returns the parameters
*CatalogueApi* | [**catalogue_session_id_datasetparameter_put**](docs/CatalogueApi.md#catalogue_session_id_datasetparameter_put) | **PUT** /catalogue/{sessionId}/datasetparameter | Update a value of a dataset parameter
*CatalogueApi* | [**catalogue_session_id_datasetparameter_values_get**](docs/CatalogueApi.md#catalogue_session_id_datasetparameter_values_get) | **GET** /catalogue/{sessionId}/datasetparameter/values | Returns the values of the parameters
*CatalogueApi* | [**catalogue_session_id_files_download_get**](docs/CatalogueApi.md#catalogue_session_id_files_download_get) | **GET** /catalogue/{sessionId}/files/download | Download the file associated to a sample
*CatalogueApi* | [**catalogue_session_id_files_get**](docs/CatalogueApi.md#catalogue_session_id_files_get) | **GET** /catalogue/{sessionId}/files | Get the list of the files linked to a sample
*CatalogueApi* | [**catalogue_session_id_files_upload_post**](docs/CatalogueApi.md#catalogue_session_id_files_upload_post) | **POST** /catalogue/{sessionId}/files/upload | Upload a file and information linked to a sample
*CatalogueApi* | [**catalogue_session_id_instruments_get**](docs/CatalogueApi.md#catalogue_session_id_instruments_get) | **GET** /catalogue/{sessionId}/instruments | Returns all instruments linked to the user
*CatalogueApi* | [**catalogue_session_id_investigation_get**](docs/CatalogueApi.md#catalogue_session_id_investigation_get) | **GET** /catalogue/{sessionId}/investigation | Get investigations by sessionId
*CatalogueApi* | [**catalogue_session_id_investigation_id_investigation_id_investigationusers_delete**](docs/CatalogueApi.md#catalogue_session_id_investigation_id_investigation_id_investigationusers_delete) | **DELETE** /catalogue/{sessionId}/investigation/id/{investigationId}/investigationusers | Deletes a user from an investigation. Only allowed to PI, LocalContact and Beamline staff
*CatalogueApi* | [**catalogue_session_id_investigation_id_investigation_id_investigationusers_get**](docs/CatalogueApi.md#catalogue_session_id_investigation_id_investigation_id_investigationusers_get) | **GET** /catalogue/{sessionId}/investigation/id/{investigationId}/investigationusers | Gets users involved in a investigation
*CatalogueApi* | [**catalogue_session_id_investigation_id_investigation_id_investigationusers_post**](docs/CatalogueApi.md#catalogue_session_id_investigation_id_investigation_id_investigationusers_post) | **POST** /catalogue/{sessionId}/investigation/id/{investigationId}/investigationusers | Add users to an investigation. Only allowed to PI, LocalContact and Beamline staff
*CatalogueApi* | [**catalogue_session_id_investigation_id_investigation_id_sample_get**](docs/CatalogueApi.md#catalogue_session_id_investigation_id_investigation_id_sample_get) | **GET** /catalogue/{sessionId}/investigation/id/{investigationId}/sample | Gets samples for a given investigationId
*CatalogueApi* | [**catalogue_session_id_investigation_investigation_id_user_get**](docs/CatalogueApi.md#catalogue_session_id_investigation_investigation_id_user_get) | **GET** /catalogue/{sessionId}/investigation/{investigationId}/user | Get user list of ICAT if the user if PI or LocalContact of the investigation, or InstrumentScientist or Administrator
*CatalogueApi* | [**catalogue_session_id_investigation_timeline_get**](docs/CatalogueApi.md#catalogue_session_id_investigation_timeline_get) | **GET** /catalogue/{sessionId}/investigation/timeline | Gets investigation timeline for a given instrumentname
*CatalogueApi* | [**catalogue_session_id_sample_parameters_id_put**](docs/CatalogueApi.md#catalogue_session_id_sample_parameters_id_put) | **PUT** /catalogue/{sessionId}/sampleParameters/{id} | Update sample parameter (description only if it is an editable sample or only sample comment)
*CatalogueApi* | [**catalogue_session_id_samples_get**](docs/CatalogueApi.md#catalogue_session_id_samples_get) | **GET** /catalogue/{sessionId}/samples | Gets samples
*CatalogueApi* | [**catalogue_session_id_samples_sample_id_page_get**](docs/CatalogueApi.md#catalogue_session_id_samples_sample_id_page_get) | **GET** /catalogue/{sessionId}/samples/{sampleId}/page | Gets sample page for a given sample
*CatalogueApi* | [**catalogue_session_id_samples_sample_id_sample_parameters_post**](docs/CatalogueApi.md#catalogue_session_id_samples_sample_id_sample_parameters_post) | **POST** /catalogue/{sessionId}/samples/{sampleId}/sampleParameters | Create sample parameter (description only if it is an editable sample, or sample comment only)
*CatalogueApi* | [**catalogue_session_id_user_get**](docs/CatalogueApi.md#catalogue_session_id_user_get) | **GET** /catalogue/{sessionId}/user | Get user list of ICAT (Restricted to administrators)
*CatalogueApi* | [**catalogue_techniques_get**](docs/CatalogueApi.md#catalogue_techniques_get) | **GET** /catalogue/techniques | Returns all techniques
*DMPApi* | [**dmp_session_id_questionnaires_get**](docs/DMPApi.md#dmp_session_id_questionnaires_get) | **GET** /dmp/{sessionId}/questionnaires | Returns a list of questionnaires for a given investigation
*DOIApi* | [**doi_prefix_suffix_datasets_get**](docs/DOIApi.md#doi_prefix_suffix_datasets_get) | **GET** /doi/{prefix}/{suffix}/datasets | Returns a set of datasets given a DOI.
*DOIApi* | [**doi_prefix_suffix_json_datacite_get**](docs/DOIApi.md#doi_prefix_suffix_json_datacite_get) | **GET** /doi/{prefix}/{suffix}/json-datacite | Returns a document in a json-datacite format with the description of the DOI
*DOIApi* | [**doi_prefix_suffix_reports_get**](docs/DOIApi.md#doi_prefix_suffix_reports_get) | **GET** /doi/{prefix}/{suffix}/reports | Returns the list of the experimental reports coming from the user portal and information needed for the display
*DOIApi* | [**doi_session_id_mint_post**](docs/DOIApi.md#doi_session_id_mint_post) | **POST** /doi/{sessionId}/mint | It mints a DOI
*DOIApi* | [**doi_session_id_reserve_post**](docs/DOIApi.md#doi_session_id_reserve_post) | **POST** /doi/{sessionId}/reserve | It reserves a DOI
*DOIApi* | [**doi_session_id_reserved_dois_get**](docs/DOIApi.md#doi_session_id_reserved_dois_get) | **GET** /doi/{sessionId}/reserved-dois | Returns the list of reserved DOIs for a given user
*DataAcquisitionApi* | [**dataacquisition_api_key_base64_post**](docs/DataAcquisitionApi.md#dataacquisition_api_key_base64_post) | **POST** /dataacquisition/{apiKey}/base64 | Uploads an image in base64 format to the investigation electronic logbook
*DataAcquisitionApi* | [**dataacquisition_api_key_dataset_get**](docs/DataAcquisitionApi.md#dataacquisition_api_key_dataset_get) | **GET** /dataacquisition/{apiKey}/dataset | Gets datasets
*DataAcquisitionApi* | [**dataacquisition_api_key_dataset_restore_post**](docs/DataAcquisitionApi.md#dataacquisition_api_key_dataset_restore_post) | **POST** /dataacquisition/{apiKey}/dataset/restore | Update the restore status of a dataset access and send an email to the users who asked for the restoration
*DataAcquisitionApi* | [**dataacquisition_api_key_events_move_post**](docs/DataAcquisitionApi.md#dataacquisition_api_key_events_move_post) | **POST** /dataacquisition/{apiKey}/events/move | move the events from one investigation to another
*DataAcquisitionApi* | [**dataacquisition_api_key_investigation_get**](docs/DataAcquisitionApi.md#dataacquisition_api_key_investigation_get) | **GET** /dataacquisition/{apiKey}/investigation | Get investigations
*DataAcquisitionApi* | [**dataacquisition_api_key_mint_post**](docs/DataAcquisitionApi.md#dataacquisition_api_key_mint_post) | **POST** /dataacquisition/{apiKey}/mint | It mints a DOI
*DataAcquisitionApi* | [**dataacquisition_api_key_notification_post**](docs/DataAcquisitionApi.md#dataacquisition_api_key_notification_post) | **POST** /dataacquisition/{apiKey}/notification | Adds an event to the logbook (for an investigation or beamline logbook). It could also be a machine event
*EWOKSApi* | [**ewoks_session_id_jobs_get**](docs/EWOKSApi.md#ewoks_session_id_jobs_get) | **GET** /ewoks/{sessionId}/jobs | Returns a list of the jobs
*EWOKSApi* | [**ewoks_session_id_jobs_post**](docs/EWOKSApi.md#ewoks_session_id_jobs_post) | **POST** /ewoks/{sessionId}/jobs | Launch a job
*EWOKSApi* | [**ewoks_session_id_jobs_put**](docs/EWOKSApi.md#ewoks_session_id_jobs_put) | **PUT** /ewoks/{sessionId}/jobs | updates a job
*EWOKSApi* | [**ewoks_session_id_workflows_get**](docs/EWOKSApi.md#ewoks_session_id_workflows_get) | **GET** /ewoks/{sessionId}/workflows | Returns a list with the content of the graph of each workflow
*ElasticSearchApi* | [**elasticsearch_session_id_datasets_msearch_get**](docs/ElasticSearchApi.md#elasticsearch_session_id_datasets_msearch_get) | **GET** /elasticsearch/{sessionId}/datasets/_msearch | Proxy to elastic search server
*ElasticSearchApi* | [**elasticsearch_session_id_stats_histogram_get**](docs/ElasticSearchApi.md#elasticsearch_session_id_stats_histogram_get) | **GET** /elasticsearch/{sessionId}/stats/histogram | Gets time series statistics. Only administrator and instrumentScientists are allowed
*ElasticSearchApi* | [**elasticsearch_session_id_stats_instrument_metrics_get**](docs/ElasticSearchApi.md#elasticsearch_session_id_stats_instrument_metrics_get) | **GET** /elasticsearch/{sessionId}/stats/instrument/metrics | Given an array of dates it returns the statistics for each instrument
*H5GroveApi* | [**h5grove_attr_get**](docs/H5GroveApi.md#h5grove_attr_get) | **GET** /h5grove/attr | It redirects to h5grove
*H5GroveApi* | [**h5grove_data_get**](docs/H5GroveApi.md#h5grove_data_get) | **GET** /h5grove/data | It redirects to h5grove
*H5GroveApi* | [**h5grove_meta_get**](docs/H5GroveApi.md#h5grove_meta_get) | **GET** /h5grove/meta | It redirects to h5grove
*H5GroveApi* | [**h5grove_stats_get**](docs/H5GroveApi.md#h5grove_stats_get) | **GET** /h5grove/stats | It redirects to h5grove
*IDSApi* | [**ids_session_id_data_download_get**](docs/IDSApi.md#ids_session_id_data_download_get) | **GET** /ids/{sessionId}/data/download | Redirects to IDS server to download datasets or datafiles
*IDSApi* | [**ids_session_id_datasets_restore_post**](docs/IDSApi.md#ids_session_id_datasets_restore_post) | **POST** /ids/{sessionId}/datasets/restore | Records dataset restoration request by a user and redirects to IDS server to download datasets or datafiles
*IDSApi* | [**ids_session_id_datasets_status_get**](docs/IDSApi.md#ids_session_id_datasets_status_get) | **GET** /ids/{sessionId}/datasets/status | Return the IDS status of the datasets specified by the datasetIds along with a sessionId.
*IDSApi* | [**ids_session_id_path_get**](docs/IDSApi.md#ids_session_id_path_get) | **GET** /ids/{sessionId}/path | Returns the location of the files or datasets
*LogbookApi* | [**logbook_api_key_investigation_name_investigation_name_instrument_name_instrument_name_event_createfrombase64_post**](docs/LogbookApi.md#logbook_api_key_investigation_name_investigation_name_instrument_name_instrument_name_event_createfrombase64_post) | **POST** /logbook/{apiKey}/investigation/name/{investigationName}/instrument/name/{instrumentName}/event/createfrombase64 | Create an event given a base64 string. It requires the API token. This is used on the spec beamlines from the metadata manager
*LogbookApi* | [**logbook_api_key_investigation_name_investigation_name_instrument_name_instrument_name_event_post**](docs/LogbookApi.md#logbook_api_key_investigation_name_investigation_name_instrument_name_instrument_name_event_post) | **POST** /logbook/{apiKey}/investigation/name/{investigationName}/instrument/name/{instrumentName}/event | This is used on the spec beamlines from the metadata manager
*LogbookApi* | [**logbook_session_id_event_count_get**](docs/LogbookApi.md#logbook_session_id_event_count_get) | **GET** /logbook/{sessionId}/event/count | Count events
*LogbookApi* | [**logbook_session_id_event_createfrombase64_post**](docs/LogbookApi.md#logbook_session_id_event_createfrombase64_post) | **POST** /logbook/{sessionId}/event/createfrombase64 | Create an event given a base64 string
*LogbookApi* | [**logbook_session_id_event_dates_get**](docs/LogbookApi.md#logbook_session_id_event_dates_get) | **GET** /logbook/{sessionId}/event/dates | Lists events dates
*LogbookApi* | [**logbook_session_id_event_get**](docs/LogbookApi.md#logbook_session_id_event_get) | **GET** /logbook/{sessionId}/event | Lists events
*LogbookApi* | [**logbook_session_id_event_page_get**](docs/LogbookApi.md#logbook_session_id_event_page_get) | **GET** /logbook/{sessionId}/event/page | Gets the number of page where the event is
*LogbookApi* | [**logbook_session_id_event_post**](docs/LogbookApi.md#logbook_session_id_event_post) | **POST** /logbook/{sessionId}/event | Creates an event
*LogbookApi* | [**logbook_session_id_event_put**](docs/LogbookApi.md#logbook_session_id_event_put) | **PUT** /logbook/{sessionId}/event | Updates an event
*LogbookApi* | [**logbook_session_id_event_remove_put**](docs/LogbookApi.md#logbook_session_id_event_remove_put) | **PUT** /logbook/{sessionId}/event/remove | Flag events as removed
*LogbookApi* | [**logbook_session_id_event_restore_put**](docs/LogbookApi.md#logbook_session_id_event_restore_put) | **PUT** /logbook/{sessionId}/event/restore | Flag events as restored by setting removed &#x3D; false for each event. InvestigationId is mandatory
*LogbookApi* | [**logbook_session_id_events_patch**](docs/LogbookApi.md#logbook_session_id_events_patch) | **PATCH** /logbook/{sessionId}/events | Updates the tags of a list of events
*LogbookApi* | [**logbook_session_id_stats_count_get**](docs/LogbookApi.md#logbook_session_id_stats_count_get) | **GET** /logbook/{sessionId}/stats/count | Counts number of event for date range
*LogbookApi* | [**logbook_session_id_stats_investigation_get**](docs/LogbookApi.md#logbook_session_id_stats_investigation_get) | **GET** /logbook/{sessionId}/stats/investigation | Lists statistics on events for each investigation that are allocated in the date range
*LogbookApi* | [**logbook_session_id_tag_get**](docs/LogbookApi.md#logbook_session_id_tag_get) | **GET** /logbook/{sessionId}/tag | GET all tags available, (ie used in the investigation or not) for a given logbook including global, beamline specific and investigation specific tags. Tags available but not used are also retrieved.
*LogbookApi* | [**logbook_session_id_tag_post**](docs/LogbookApi.md#logbook_session_id_tag_post) | **POST** /logbook/{sessionId}/tag | Create an investigation tag for a given investigationId
*LogbookApi* | [**logbook_session_id_tag_put**](docs/LogbookApi.md#logbook_session_id_tag_put) | **PUT** /logbook/{sessionId}/tag | Update an investigation tag
*MESSAGESApi* | [**messages_get**](docs/MESSAGESApi.md#messages_get) | **GET** /messages | Returns the messages
*MESSAGESApi* | [**messages_session_id_information_put**](docs/MESSAGESApi.md#messages_session_id_information_put) | **PUT** /messages/{sessionId}/information | Update an information message
*OAIPMHApi* | [**oaipmh_request_get**](docs/OAIPMHApi.md#oaipmh_request_get) | **GET** /oaipmh/request | Proxy to OAI-PMH server
*PanoscApi* | [**api_scoring_items_get**](docs/PanoscApi.md#api_scoring_items_get) | **GET** /api/scoring/items | Gets public datasets by date and then it parses into items for the scoring database
*ResourceApi* | [**resource_session_id_file_download_get**](docs/ResourceApi.md#resource_session_id_file_download_get) | **GET** /resource/{sessionId}/file/download | Downloads a resource
*ResourceApi* | [**resource_session_id_file_upload_post**](docs/ResourceApi.md#resource_session_id_file_upload_post) | **POST** /resource/{sessionId}/file/upload | Uploads a file to ICAT+
*SampleMetadataApi* | [**samplemetadata_session_id_samples_delete**](docs/SampleMetadataApi.md#samplemetadata_session_id_samples_delete) | **DELETE** /samplemetadata/{sessionId}/samples | Delete samples with metadata information for the given sampleIds
*SampleMetadataApi* | [**samplemetadata_session_id_samples_files_delete**](docs/SampleMetadataApi.md#samplemetadata_session_id_samples_files_delete) | **DELETE** /samplemetadata/{sessionId}/samples/files | Delete a metadata file
*SampleMetadataApi* | [**samplemetadata_session_id_samples_files_get**](docs/SampleMetadataApi.md#samplemetadata_session_id_samples_files_get) | **GET** /samplemetadata/{sessionId}/samples/files | Download a metadata file
*SampleMetadataApi* | [**samplemetadata_session_id_samples_files_post**](docs/SampleMetadataApi.md#samplemetadata_session_id_samples_files_post) | **POST** /samplemetadata/{sessionId}/samples/files | Upload one or more new files
*SampleMetadataApi* | [**samplemetadata_session_id_samples_get**](docs/SampleMetadataApi.md#samplemetadata_session_id_samples_get) | **GET** /samplemetadata/{sessionId}/samples | Returns the list of the samples with metadata information, user from the sessionId
*SampleMetadataApi* | [**samplemetadata_session_id_samples_post**](docs/SampleMetadataApi.md#samplemetadata_session_id_samples_post) | **POST** /samplemetadata/{sessionId}/samples | Creates a new sample
*SampleMetadataApi* | [**samplemetadata_session_id_samples_put**](docs/SampleMetadataApi.md#samplemetadata_session_id_samples_put) | **PUT** /samplemetadata/{sessionId}/samples | Update an existing sample
*SessionApi* | [**session_post**](docs/SessionApi.md#session_post) | **POST** /session | This is used to log into the app
*SessionApi* | [**session_session_id_delete**](docs/SessionApi.md#session_session_id_delete) | **DELETE** /session/{sessionId} | Log out
*SessionApi* | [**session_session_id_get**](docs/SessionApi.md#session_session_id_get) | **GET** /session/{sessionId} | Gets information about the session in ICAT
*SessionApi* | [**session_session_id_put**](docs/SessionApi.md#session_session_id_put) | **PUT** /session/{sessionId} | This is used to refresh the current session. It returns code 204 if refreshed
*TrackingApi* | [**tracking_session_id_address_get**](docs/TrackingApi.md#tracking_session_id_address_get) | **GET** /tracking/{sessionId}/address | Returns all addresses associated to an user
*TrackingApi* | [**tracking_session_id_investigation_id_investigation_id_address_delete**](docs/TrackingApi.md#tracking_session_id_investigation_id_investigation_id_address_delete) | **DELETE** /tracking/{sessionId}/investigation/id/{investigationId}/address | Deletes an existin address
*TrackingApi* | [**tracking_session_id_investigation_id_investigation_id_address_get**](docs/TrackingApi.md#tracking_session_id_investigation_id_investigation_id_address_get) | **GET** /tracking/{sessionId}/investigation/id/{investigationId}/address | Returns a list of addresses associated to an investigation
*TrackingApi* | [**tracking_session_id_investigation_id_investigation_id_address_post**](docs/TrackingApi.md#tracking_session_id_investigation_id_investigation_id_address_post) | **POST** /tracking/{sessionId}/investigation/id/{investigationId}/address | Creates a address
*TrackingApi* | [**tracking_session_id_investigation_id_investigation_id_address_put**](docs/TrackingApi.md#tracking_session_id_investigation_id_investigation_id_address_put) | **PUT** /tracking/{sessionId}/investigation/id/{investigationId}/address | Modifies an existin address
*TrackingApi* | [**tracking_session_id_investigation_id_investigation_id_parcel_id_parcel_id_item_item_id_delete**](docs/TrackingApi.md#tracking_session_id_investigation_id_investigation_id_parcel_id_parcel_id_item_item_id_delete) | **DELETE** /tracking/{sessionId}/investigation/id/{investigationId}/parcel/id/{parcelId}/item/{itemId} | Deletes an item
*TrackingApi* | [**tracking_session_id_investigation_id_investigation_id_parcel_id_parcel_id_item_item_id_put**](docs/TrackingApi.md#tracking_session_id_investigation_id_investigation_id_parcel_id_parcel_id_item_item_id_put) | **PUT** /tracking/{sessionId}/investigation/id/{investigationId}/parcel/id/{parcelId}/item/{itemId} | Edits an item
*TrackingApi* | [**tracking_session_id_investigation_id_investigation_id_parcel_id_parcel_id_item_post**](docs/TrackingApi.md#tracking_session_id_investigation_id_investigation_id_parcel_id_parcel_id_item_post) | **POST** /tracking/{sessionId}/investigation/id/{investigationId}/parcel/id/{parcelId}/item | Creates an item associated to a parcel
*TrackingApi* | [**tracking_session_id_investigation_id_investigation_id_parcel_id_parcel_id_labels_get**](docs/TrackingApi.md#tracking_session_id_investigation_id_investigation_id_parcel_id_parcel_id_labels_get) | **GET** /tracking/{sessionId}/investigation/id/{investigationId}/parcel/id/{parcelId}/labels | Returns a file with the labels
*TrackingApi* | [**tracking_session_id_investigation_id_investigation_id_parcel_id_parcel_id_parcel_status_status_put**](docs/TrackingApi.md#tracking_session_id_investigation_id_investigation_id_parcel_id_parcel_id_parcel_status_status_put) | **PUT** /tracking/{sessionId}/investigation/id/{investigationId}/parcel/id/{parcelId}/parcel/status/{status} | Modifies a the status of a parcel
*TrackingApi* | [**tracking_session_id_parcel_get**](docs/TrackingApi.md#tracking_session_id_parcel_get) | **GET** /tracking/{sessionId}/parcel | Lists parcels
*TrackingApi* | [**tracking_session_id_parcel_post**](docs/TrackingApi.md#tracking_session_id_parcel_post) | **POST** /tracking/{sessionId}/parcel | It does create or update a new parcel
*TrackingApi* | [**tracking_session_id_parcel_put**](docs/TrackingApi.md#tracking_session_id_parcel_put) | **PUT** /tracking/{sessionId}/parcel | It does create or update a new parcel
*TrackingApi* | [**tracking_session_id_setup_get**](docs/TrackingApi.md#tracking_session_id_setup_get) | **GET** /tracking/{sessionId}/setup | Returns the the list of container types and parameters allowed to define experiment and processing plans
*TrackingApi* | [**tracking_session_id_shipment_delete**](docs/TrackingApi.md#tracking_session_id_shipment_delete) | **DELETE** /tracking/{sessionId}/shipment | Deletes a shipment
*TrackingApi* | [**tracking_session_id_shipment_get**](docs/TrackingApi.md#tracking_session_id_shipment_get) | **GET** /tracking/{sessionId}/shipment | Lists shipments associated to an investigation
*TrackingApi* | [**tracking_session_id_shipment_id_shipment_id_parcel_delete**](docs/TrackingApi.md#tracking_session_id_shipment_id_shipment_id_parcel_delete) | **DELETE** /tracking/{sessionId}/shipment/id/{shipmentId}/parcel | Deletes a parcel
*TrackingApi* | [**tracking_session_id_shipment_post**](docs/TrackingApi.md#tracking_session_id_shipment_post) | **POST** /tracking/{sessionId}/shipment | Creates a shipment associated to an investigation
*TrackingApi* | [**tracking_session_id_shipment_put**](docs/TrackingApi.md#tracking_session_id_shipment_put) | **PUT** /tracking/{sessionId}/shipment | Modifies a shipment associated to an investigation
*USERSApi* | [**users_session_id_preferences_get**](docs/USERSApi.md#users_session_id_preferences_get) | **GET** /users/{sessionId}/preferences | Returns the list of the user&#39;s preferences, user from the sessionId
*USERSApi* | [**users_session_id_preferences_put**](docs/USERSApi.md#users_session_id_preferences_put) | **PUT** /users/{sessionId}/preferences | Update the user&#39;s preferences, user from the sessionId
*UserManagementApi* | [**catalogue_session_id_instrumentscientist_delete**](docs/UserManagementApi.md#catalogue_session_id_instrumentscientist_delete) | **DELETE** /catalogue/{sessionId}/instrumentscientist | It deletes InstrumentScientists
*UserManagementApi* | [**catalogue_session_id_instrumentscientist_get**](docs/UserManagementApi.md#catalogue_session_id_instrumentscientist_get) | **GET** /catalogue/{sessionId}/instrumentscientist | Get all InstrumentScientists
*UserManagementApi* | [**catalogue_session_id_instrumentscientist_put**](docs/UserManagementApi.md#catalogue_session_id_instrumentscientist_put) | **PUT** /catalogue/{sessionId}/instrumentscientist | It creates InstrumentScientists
*UserManagementApi* | [**catalogue_session_id_user_name_name_instrumentscientist_get**](docs/UserManagementApi.md#catalogue_session_id_user_name_name_instrumentscientist_get) | **GET** /catalogue/{sessionId}/user/name/{name}/instrumentscientist | Get instrumentScientist by user name


## Documentation For Models

 - [Actions](docs/Actions.md)
 - [Address](docs/Address.md)
 - [AuthorsInner](docs/AuthorsInner.md)
 - [CacheStats](docs/CacheStats.md)
 - [CacheUserStorage](docs/CacheUserStorage.md)
 - [CatalogueSessionIdInstrumentscientistDeleteRequest](docs/CatalogueSessionIdInstrumentscientistDeleteRequest.md)
 - [CatalogueSessionIdInstrumentscientistPutRequest](docs/CatalogueSessionIdInstrumentscientistPutRequest.md)
 - [CatalogueSessionIdInvestigationIdInvestigationIdInvestigationusersPostRequest](docs/CatalogueSessionIdInvestigationIdInvestigationIdInvestigationusersPostRequest.md)
 - [Credentials](docs/Credentials.md)
 - [DataacquisitionApiKeyBase64PostRequest](docs/DataacquisitionApiKeyBase64PostRequest.md)
 - [DataacquisitionApiKeyDatasetRestorePostRequest](docs/DataacquisitionApiKeyDatasetRestorePostRequest.md)
 - [DataacquisitionApiKeyMintPost200Response](docs/DataacquisitionApiKeyMintPost200Response.md)
 - [DataacquisitionApiKeyMintPostRequest](docs/DataacquisitionApiKeyMintPostRequest.md)
 - [Datacollection](docs/Datacollection.md)
 - [DatacollectionDataCollectionDatasetsInner](docs/DatacollectionDataCollectionDatasetsInner.md)
 - [DatacollectionDataCollectionDatasetsInnerDataset](docs/DatacollectionDataCollectionDatasetsInnerDataset.md)
 - [Datafile](docs/Datafile.md)
 - [Datafilelight](docs/Datafilelight.md)
 - [Dataset](docs/Dataset.md)
 - [DatasetDocument](docs/DatasetDocument.md)
 - [DatasetDocumentInvestigation](docs/DatasetDocumentInvestigation.md)
 - [DatasetDocumentParametersInner](docs/DatasetDocumentParametersInner.md)
 - [DatasetTechniquesInner](docs/DatasetTechniquesInner.md)
 - [Datasetaccess](docs/Datasetaccess.md)
 - [Datasetparameter](docs/Datasetparameter.md)
 - [Dmpquestionnaire](docs/Dmpquestionnaire.md)
 - [DoiData](docs/DoiData.md)
 - [DoiSessionIdMintPostRequest](docs/DoiSessionIdMintPostRequest.md)
 - [DoiSessionIdReservePostRequest](docs/DoiSessionIdReservePostRequest.md)
 - [ElasticsearchSessionIdStatsInstrumentMetricsGetRequestInner](docs/ElasticsearchSessionIdStatsInstrumentMetricsGetRequestInner.md)
 - [Event](docs/Event.md)
 - [EventContentInner](docs/EventContentInner.md)
 - [EwoksSessionIdJobsPostRequest](docs/EwoksSessionIdJobsPostRequest.md)
 - [EwoksSessionIdJobsPutRequest](docs/EwoksSessionIdJobsPutRequest.md)
 - [EwoksSessionIdJobsPutRequestStep](docs/EwoksSessionIdJobsPutRequestStep.md)
 - [ExpreportsInner](docs/ExpreportsInner.md)
 - [IdsSessionIdDatasetsRestorePostRequest](docs/IdsSessionIdDatasetsRestorePostRequest.md)
 - [Instrument](docs/Instrument.md)
 - [Instrumentscientist](docs/Instrumentscientist.md)
 - [InstrumentscientistInstrument](docs/InstrumentscientistInstrument.md)
 - [InstrumentscientistMod](docs/InstrumentscientistMod.md)
 - [InstrumentscientistUser](docs/InstrumentscientistUser.md)
 - [Investigation](docs/Investigation.md)
 - [InvestigationInstrument](docs/InvestigationInstrument.md)
 - [InvestigationInvestigationUsersInner](docs/InvestigationInvestigationUsersInner.md)
 - [InvestigationInvestigationUsersInnerUser](docs/InvestigationInvestigationUsersInnerUser.md)
 - [InvestigationType](docs/InvestigationType.md)
 - [Investigationlight](docs/Investigationlight.md)
 - [Investigationusers](docs/Investigationusers.md)
 - [Item](docs/Item.md)
 - [Job](docs/Job.md)
 - [JobInvestigationsInner](docs/JobInvestigationsInner.md)
 - [JsonDatacite](docs/JsonDatacite.md)
 - [JsonDataciteDatesInner](docs/JsonDataciteDatesInner.md)
 - [JsonDataciteSubjectsInner](docs/JsonDataciteSubjectsInner.md)
 - [JsonDataciteTitles](docs/JsonDataciteTitles.md)
 - [LogbookFilters](docs/LogbookFilters.md)
 - [LogbookInvestigationStat](docs/LogbookInvestigationStat.md)
 - [LogbookInvestigationStatCount](docs/LogbookInvestigationStatCount.md)
 - [LogbookSessionIdEventCreatefrombase64PostRequest](docs/LogbookSessionIdEventCreatefrombase64PostRequest.md)
 - [LogbookSessionIdEventPutRequest](docs/LogbookSessionIdEventPutRequest.md)
 - [LogbookSessionIdEventPutRequestEvent](docs/LogbookSessionIdEventPutRequestEvent.md)
 - [LogbookSessionIdEventsPatchRequest](docs/LogbookSessionIdEventsPatchRequest.md)
 - [Member](docs/Member.md)
 - [Message](docs/Message.md)
 - [Meta](docs/Meta.md)
 - [MetaPage](docs/MetaPage.md)
 - [ModifiedObject](docs/ModifiedObject.md)
 - [Mxcutoffs](docs/Mxcutoffs.md)
 - [Mxsettings](docs/Mxsettings.md)
 - [Mxshell](docs/Mxshell.md)
 - [PaginationInner](docs/PaginationInner.md)
 - [Parameter](docs/Parameter.md)
 - [Parcel](docs/Parcel.md)
 - [ParcelStatus](docs/ParcelStatus.md)
 - [RecentlyVisited](docs/RecentlyVisited.md)
 - [Relateditem](docs/Relateditem.md)
 - [Resourceinformation](docs/Resourceinformation.md)
 - [ReturnParcelInformation](docs/ReturnParcelInformation.md)
 - [Sample](docs/Sample.md)
 - [SampleDatasetsInner](docs/SampleDatasetsInner.md)
 - [SampleDatasetsInnerParametersInner](docs/SampleDatasetsInnerParametersInner.md)
 - [SampleInvestigation](docs/SampleInvestigation.md)
 - [SampleInvestigationInstrument](docs/SampleInvestigationInstrument.md)
 - [Sampleinformation](docs/Sampleinformation.md)
 - [Samplemetadata](docs/Samplemetadata.md)
 - [SamplemetadataSessionIdSamplesDelete200Response](docs/SamplemetadataSessionIdSamplesDelete200Response.md)
 - [Samplemetadatasample](docs/Samplemetadatasample.md)
 - [Samplemetadatasimplifiedsample](docs/Samplemetadatasimplifiedsample.md)
 - [Session](docs/Session.md)
 - [SessionSessionIdGet200Response](docs/SessionSessionIdGet200Response.md)
 - [Setup](docs/Setup.md)
 - [Shipment](docs/Shipment.md)
 - [Status](docs/Status.md)
 - [Tag](docs/Tag.md)
 - [Target](docs/Target.md)
 - [Technique](docs/Technique.md)
 - [Timeline](docs/Timeline.md)
 - [Tracking](docs/Tracking.md)
 - [TrackingInformation](docs/TrackingInformation.md)
 - [User](docs/User.md)
 - [Userpreferences](docs/Userpreferences.md)
 - [UserpreferencesSelection](docs/UserpreferencesSelection.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization

Endpoints do not require authorization.


## Author

demariaa@esrf.fr


